; $Id: 
;
;   * Manages a tablespace
;   * A tablespace has one or more tables
;   * Create, drop a tablespace
;   * Create, drop a table on a tablespace
;   * Open, close a cursor on a table
;
;

; Create a tablespace
;
; With a transaction, tx
; Within a file named, ts-file-pathname
; With initial size, init-size
; With extent size, ext-size
;
; Creating a tablespace is a Nested Top Action
; It is not possible to be undone, once it is completed
(defun ts-create( tx ts-file-pathname init-size ext-size)
)

; Drop a tablespace, ts
;
; With a transaction, tx
;
; Dropping a tablespace is a Nested Top Action
; It is not possible to be undone, once it is completed
(defun ts-drop( tx ts )
)

; Create a table
;
; With a transaction, tx
; On a tablespace, ts
; With a column specification, column-spec
;
; Creating a table is a Nested Top Action
; It is not possible to be undone, once it is completed
(defun ts-create-table( tx ts column-spec )
)

; Drop a table, table
;
; Dropping a table is a Nested Top Action
; It is not possible to be undone, once it is completed
(defun ts-drop-table( tx ts table )
)

; Return a table
;
; Whose id is table-id

(defun ts-table-by-id( tx ts table-id)
)

; Open a table cursor
;
; On a table, table
; With a scan condition, scan-condition
(defun ts-open-table-cursor( tx ts table scan-condition )
)

; Close a table cursor, cursor
;
(defun ts-close-table-cursor( tx ts cursor )
)
